#[non_exhaustive]pub struct Version {
pub version_id: i64,
pub modifications_count: i64,
pub created_timestamp: u64,
pub modified_timestamp: u64,
pub session_id: Option<i64>,
pub client_identity: Option<String>,
}Expand description
Metadata about the state of a record.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.version_id: i64The unique identifier of this version of the record. It changes on every
modification and is the value to pass to
expected_version_id for
compare-and-swap operations.
modifications_count: i64The number of modifications made to the record since it was created.
created_timestamp: u64The creation timestamp of the record, in milliseconds since the epoch.
modified_timestamp: u64The timestamp of the latest modification, in milliseconds since the epoch.
session_id: Option<i64>The identifier of the owning session, when the record is ephemeral.
client_identity: Option<String>The identity of the client that last modified an ephemeral record.
Implementations